==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/demo/rakuraku/uxyz/uxyz4.c <==
/* demo/rakuraku/uxyz/uxyz4.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__9 = 9;
static integer c__1 = 1;
static integer c__3 = 3;
static real c_b6 = -50.f;
static real c_b7 = 50.f;
static real c_b8 = 1e3f;
static real c_b9 = .4f;
static real c_b10 = .2f;
static real c_b11 = .8f;
static integer c__2 = 2;
static real c_b16 = 5.f;
static real c_b17 = 20.f;
static real c_b23 = 0.f;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Main program */ int MAIN__(void)
{
    /* Builtin functions */
    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
	    e_wsle(void), s_rsle(cilist *), e_rsle(void);

    /* Local variables */
    static integer iws;
    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
	     grswnd_(real *, real *, real *, real *), uliset_(char *, integer 
	    *, ftnlen), grstrf_(void), ulylog_(char *, integer *, integer *, 
	    ftnlen), grstrn_(integer *), uxaxdv_(char *, real *, real *, 
	    ftnlen), sgpwsn_(void), grsvpt_(real *, real *, real *, real *), 
	    uxmttl_(char *, char *, real *, ftnlen, ftnlen), uxsttl_(char *, 
	    char *, real *, ftnlen, ftnlen), uysttl_(char *, char *, real *, 
	    ftnlen, ftnlen);

    /* Fortran I/O blocks */
    static cilist io___1 = { 0, 6, 0, 0, 0 };
    static cilist io___2 = { 0, 5, 0, 0, 0 };


    s_wsle(&io___1);
    do_lio(&c__9, &c__1, " WORKSTATION ID (I) ? ;", (ftnlen)23);
    e_wsle();
    sgpwsn_();
    s_rsle(&io___2);
    do_lio(&c__3, &c__1, (char *)&iws, (ftnlen)sizeof(integer));
    e_rsle();
    gropn_(&iws);
    grfrm_();
    grswnd_(&c_b6, &c_b7, &c_b8, &c_b9);
    grsvpt_(&c_b10, &c_b11, &c_b10, &c_b11);
    grstrn_(&c__2);
    grstrf_();
    uxaxdv_("B", &c_b16, &c_b17, (ftnlen)1);
    uxaxdv_("T", &c_b16, &c_b17, (ftnlen)1);
    uxsttl_("B", "LATITUDE (deg)", &c_b23, (ftnlen)1, (ftnlen)14);
    uliset_("IYTYPE", &c__3, (ftnlen)6);
    ulylog_("L", &c__3, &c__9, (ftnlen)1);
    ulylog_("R", &c__3, &c__9, (ftnlen)1);
    uysttl_("L", "PRESSURE (hPa)", &c_b23, (ftnlen)1, (ftnlen)14);
    uxmttl_("T", "UXAXDV/ULYLOG", &c_b23, (ftnlen)1, (ftnlen)13);
    grcls_();
    return 0;
} /* MAIN__ */

/* Main program alias */ int uxyz4_ () { MAIN__ (); return 0; }

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/demo/rakuraku/uxyz/uxyz4.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__9 = 9;
static integer c__1 = 1;
static integer c__3 = 3;
static real c_b6 = -50.f;
static real c_b7 = 50.f;
static real c_b8 = 1e3f;
static real c_b9 = .4f;
static real c_b10 = .2f;
static real c_b11 = .8f;
static integer c__2 = 2;
static real c_b16 = 5.f;
static real c_b17 = 20.f;
static real c_b23 = 0.f;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Main program */ int MAIN__(void)
{
    /* Builtin functions */
    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
	    e_wsle(void), s_rsle(cilist *), e_rsle(void);

    /* Local variables */
    static integer iws;
    extern /* Subroutine */ int grcls_(void), grfrm_(void), gropn_(integer *),
	     grswnd_(real *, real *, real *, real *), uliset_(char *, integer 
	    *, ftnlen), grstrf_(void), ulylog_(char *, integer *, integer *, 
	    ftnlen), grstrn_(integer *), uxaxdv_(char *, real *, real *, 
	    ftnlen), sgpwsn_(void), grsvpt_(real *, real *, real *, real *), 
	    uxmttl_(char *, char *, real *, ftnlen, ftnlen), uxsttl_(char *, 
	    char *, real *, ftnlen, ftnlen), uysttl_(char *, char *, real *, 
	    ftnlen, ftnlen);

    /* Fortran I/O blocks */
    static cilist io___1 = { 0, 6, 0, 0, 0 };
    static cilist io___2 = { 0, 5, 0, 0, 0 };


    s_wsle(&io___1);
    do_lio(&c__9, &c__1, " WORKSTATION ID (I) ? ;", (ftnlen)23);
    e_wsle();
    sgpwsn_();
    s_rsle(&io___2);
    do_lio(&c__3, &c__1, (char *)&iws, (ftnlen)sizeof(integer));
    e_rsle();
    gropn_(&iws);
    grfrm_();
    grswnd_(&c_b6, &c_b7, &c_b8, &c_b9);
    grsvpt_(&c_b10, &c_b11, &c_b10, &c_b11);
    grstrn_(&c__2);
    grstrf_();
    uxaxdv_("B", &c_b16, &c_b17, (ftnlen)1);
    uxaxdv_("T", &c_b16, &c_b17, (ftnlen)1);
    uxsttl_("B", "LATITUDE (deg)", &c_b23, (ftnlen)1, (ftnlen)14);
    uliset_("IYTYPE", &c__3, (ftnlen)6);
    ulylog_("L", &c__3, &c__9, (ftnlen)1);
    ulylog_("R", &c__3, &c__9, (ftnlen)1);
    uysttl_("L", "PRESSURE (hPa)", &c_b23, (ftnlen)1, (ftnlen)14);
    uxmttl_("T", "UXAXDV/ULYLOG", &c_b23, (ftnlen)1, (ftnlen)13);
    grcls_();
    return 0;
} /* MAIN__ */

/* Main program alias */ int uxyz4_ () { MAIN__ (); return 0; }
